@@ -4,7 +4,7 @@ use warnings;
 use base qw/Exporter/;
 use 5.008001;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp ();
 use Furl::ConnectionCache;
@@ -575,12 +575,20 @@ sub connect_ssl {
     my $timeout = $timeout_at - time;
     return (undef, "Cannot create SSL connection: timeout")
         if $timeout <= 0;
+
+    my $ssl_opts = $self->{ssl_opts};
+    if ($ssl_opts->{SSL_verify_mode}) {
+        unless (exists $ssl_opts->{SSL_ca_file} || exists $ssl_opts->{SSL_ca_path}) {
+            require Mozilla::CA;
+            $ssl_opts->{SSL_ca_file} = Mozilla::CA::SSL_ca_file();
+        }
+    }
     my $sock = IO::Socket::SSL->new(
         PeerHost => $host,
         PeerPort => $port,
         Timeout  => $timeout,
-        %{ $self->{ssl_opts} },
-    ) or return (undef, "Cannot create SSL connection: $!");
+        %$ssl_opts,
+    ) or return (undef, "Cannot create SSL connection: " . IO::Socket::SSL::errstr());
     _set_sockopts($sock);
     $sock;
 }
